@@ -1,4 +1,4 @@
-from collections import ItemsView, MutableMapping
+from collections.abc import MutableMapping
 
 
 class DocumentDict(MutableMapping):
